@@ -11,11 +11,15 @@ a separate base
 import sys
 import copy
 
-from collections import MutableSet, Sized, Set
 
 from ruamel_yaml.compat import ordereddict, PY2, string_types
 from ruamel_yaml.scalarstring import ScalarString
 
+if PY2:
+    from collections import MutableSet, Sized, Set
+else:
+    from collections.abc import MutableSet, Sized, Set
+
 if False:  # MYPY
     from typing import Any, Dict, Optional, List, Union  # NOQA
 
